==> haskell-decimal-0.5.2-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-EuHKrdxxLfM647iRI612ur
key:                  Decimal-0.5.2-EuHKrdxxLfM647iRI612ur
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  2c4143844e9f75547261f3b187e59d5c
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-EuHKrdxxLfM647iRI612ur
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.2-177-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-5cj0SAP9Brc4OvqOhAwss9
key:                  Decimal-0.5.2-5cj0SAP9Brc4OvqOhAwss9
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  6bef6772ba166dfe8bb7135321f8fe15
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-5cj0SAP9Brc4OvqOhAwss9
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
